##  Resetting Your Password
If you forgot your password, you can reset it. Follow these steps:
  1. On the sign-in page, click Recover your password.
  2. Enter your email address that you previously used to sign in to SAP LeanIX, then click Send.
  3. Follow the instructions in the email that you receive.


Once you’ve reset your password, use the new password to sign in to SAP LeanIX.
YesNo
Send
